unit ucuEfetuarEmprestimo;


interface

uses
  utuStateMachine, utuRequest, ucuUseCase;

type
  ucEfetuarEmprestimo = class(ucUseCase)
  public
    procedure Initialize; Override;
    procedure Finalize; Override;
  published
    procedure Effect_PesquisarUsuario(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_EscolherUsuario(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_RealizarEmprestimo(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_PesquisarExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_RemoverExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_Confirmar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_CancelarConfirmacao(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_CancelarEscolhaExemplar(piRequest: utRequest; piTransition: utTransition);
    procedure Effect_SelecionarExemplar(piRequest: utRequest; piTransition: utTransition);
  end;

implementation

uses
  ucuManager,
  utuMessage {define utField},
  acuFramework,
  utuEmprestimoOQL,
  acuObject {define acEnumerator},
  nguUsuario;

procedure ucEfetuarEmprestimo.Initialize;
begin
  inherited;
end;

procedure ucEfetuarEmprestimo.Finalize;
begin

  inherited;
end;

procedure ucEfetuarEmprestimo.Effect_PesquisarUsuario(piRequest: utRequest; piTransition: utTransition);
var
  lFieldUsuario,
  lFieldUsuarios: utField;
  lOQL: IObterUsuarios;
  lListUsuarios: acPersistentObjectList;
  lEnumUsuario: acEnumerator;
  lUsuario: ngUsuario;
begin
  lFieldUsuario := piRequest.Message.RootField.FieldByName('Usuario');

  lOQL := utEmprestimoOQL.ObterUsuarios(Self.Session);

  lFieldUsuarios := piRequest.Response.RootField.AddField('Usuarios');

  lListUsuarios := acPersistentObjectList.Create(ngUsuario);
  try

    if lFieldUsuario.HasAttribute('Nome')
      then lOQL.Param_nome.Value := lFieldUsuario.AttributeByName('Nome').AsString
      else lOQL.Param_nome.SetNull;

    if lFieldUsuario.HasAttribute('CPF')
      then lOQL.Param_cpf.Value := lFieldUsuario.AttributeByName('CPF').AsString
      else lOQL.Param_cpf.SetNull;

    lOQL.LoadList(lListUsuarios);

    lEnumUsuario := acEnumerator.Create(lListUsuarios);
    try
      while not lEnumUsuario.EOL do
      begin
        lUsuario := lEnumUsuario.Current as ngUsuario;
        lUsuario.toXML(lFieldUsuarios.AddField('Usuario'));
        lEnumUsuario.MoveNext;
      end;
    finally
      lEnumUsuario.Free;
    end;


  finally
    lListUsuarios.Free;
  end;

  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_EscolherUsuario(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_RealizarEmprestimo(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_PesquisarExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_RemoverExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_Confirmar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_CancelarConfirmacao(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_CancelarEscolhaExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;

procedure ucEfetuarEmprestimo.Effect_SelecionarExemplar(piRequest: utRequest; piTransition: utTransition);
begin
  
  
  piRequest.Processed := True;
end;


initialization

  gucManager.RegisterClass(3220,ucEfetuarEmprestimo);

end.
